﻿// Copyright © 2011 - Present RealDimensions Software, LLC
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// 
// You may obtain a copy of the License at
// 
// 	http://www.apache.org/licenses/LICENSE-2.0
// 
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

namespace chocolatey.tests.integration.infrastructure.cryptography
{
    using System;
    using System.IO;
    using System.Reflection;
    using System.Security.Cryptography;
    using Should;
    using chocolatey.infrastructure.cryptography;
    using chocolatey.infrastructure.filesystem;

    public class CrytpoHashProviderSpecs
    {
        public abstract class CrytpoHashProviderSpecsBase : TinySpec
        {
            protected CrytpoHashProvider Provider;
            protected DotNetFileSystem FileSystem;
            protected string ContextDirectory;

            public override void Context()
            {
                FileSystem = new DotNetFileSystem();
                Provider = new CrytpoHashProvider(FileSystem,CryptoHashProviderType.Md5);
                ContextDirectory = FileSystem.combine_paths(FileSystem.get_directory_name(Assembly.GetExecutingAssembly().CodeBase.Replace("file:///", string.Empty)), "context");
            }
        }

        public class when_HashProvider_provides_a_hash : CrytpoHashProviderSpecsBase
        {
            private string result;
            private string filePath;

            public override void Context()
            {
                base.Context();
                filePath = FileSystem.combine_paths(ContextDirectory, "testing.packages.config");
            }

            public override void Because()
            {
                result = Provider.hash_file(filePath);
            }

            [Fact]
            public void should_provide_the_correct_hash_based_on_a_checksum()
            {
                var expected = BitConverter.ToString(MD5.Create().ComputeHash(File.ReadAllBytes(filePath))).Replace("-", string.Empty);

                result.ShouldEqual(expected);
            }
        }
    }
}